const plugins = require('./webpack.plugins');
const path = require('path');

const devServer = {
  devtool: 'cheap-module-source-map',
  devServer: {
    port: 3000,
  },
};

const shared = {
  resolve: {
    alias: {
      'react': 'preact-compat/dist/preact-compat.js',
      'react-dom': 'preact-compat/dist/preact-compat.js',
    },
  },
  entry: './source/index.js',
  output: {
    path: path.resolve('dist'),
    filename: 'bundle.js',
  },
};

const babel = { test: /\.js$/, use: 'babel-loader', include: path.resolve(__dirname, 'source') };
const flow = { test: /\.js$/, use: 'flowtype-loader', include: path.resolve(__dirname, 'source'), enforce: 'pre' };

if (process.env.NODE_ENV === 'development') {
  module.exports = {
    ...shared,
    ...devServer,
    module: {
      rules: [
        flow,
        babel,
      ],
    },
    plugins: [ ...plugins.development ],
  };
} else {
  module.exports = {
    ...shared,
    module: {
      rules: [
        babel,
      ],
    },
    plugins: [ ...plugins.production ],
  };
}
